@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 extern gboolean userbreak;
 
 
@@ -37,4 +42,9 @@ GtkWidget *
 abort_dialog (const gchar *label);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
