@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 /******************************************************************************
 *                                                                             *
 * ja:メニュー関数群                                                           *
@@ -172,4 +177,9 @@ command_conf (gpointer   callback_data,
               GtkWidget *widget);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
