@@ -139,7 +139,7 @@ file_add_edit (const gchar *file, gint *same)
           child = g_list_nth_data (glist, i);
           tmaid = g_object_get_data (G_OBJECT (child), "user_data");
           name1 = g_basename (tmaid->file);
-          if (g_strfilecmp (name0, name1) == 0)
+          if (!g_strfilecmp (name0, name1))
             {
               if (tmaid->same < 0)
                 {
@@ -212,7 +212,7 @@ file_delete_edit (const gchar *file)
           {
             child = g_list_nth_data (glist, i);
             tmaid = g_object_get_data (G_OBJECT (child), "user_data");
-            if (!g_strfilecmp (file,  tmaid->file))
+            if (!g_strfilecmp (file, tmaid->file))
               {
                 tmaid->same = -1;
                 utf8str = g_filename_to_utf8 (tmaid->file, -1,
@@ -647,9 +647,18 @@ file_open_edit (const gchar *file)
                             | GDK_FOCUS_CHANGE_MASK);
   GTK_WIDGET_SET_FLAGS (tmaid->drawing, GTK_CAN_FOCUS);
   /* ja:フォント */
-  gtk_widget_modify_font (window, tmaid->ft.font_name != NULL
-                    ? pango_font_description_from_string (tmaid->ft.font_name)
-                    : pango_font_description_copy (system_font));
+  if (tmaid->ft.font_name)
+    {
+      PangoFontDescription *desc;
+
+      desc = pango_font_description_from_string (tmaid->ft.font_name);
+      gtk_widget_modify_font (window, desc);
+      pango_font_description_free (desc);
+    }
+  else
+    {
+      gtk_widget_modify_font (window, system_font);
+    }
   tmaid->layout = gtk_widget_create_pango_layout (window, NULL);
   charset_size (tmaid->layout, &tmaid->font_width, &tmaid->font_height,
                                                             tmaid->font_buf);
@@ -681,7 +690,7 @@ file_open_edit (const gchar *file)
   g_signal_connect (G_OBJECT (tmaid->menu_item), "activate",
                             G_CALLBACK (signal_activate_menu_window), table);
   gtk_menu_append (GTK_MENU (menu_shell), tmaid->menu_item);
-  gtk_widget_show(tmaid->menu_item);
+  gtk_widget_show (tmaid->menu_item);
   /* ja:ボタン */
   button = gtk_button_new ();
   frame = gtk_frame_new (NULL);
