@@ -23,6 +23,11 @@
 #include "common.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 #define TMAID_VERSION_NOTICE "Text maid "VERSION" ("TMAID_BUILD_ENVIRONMENT")"
 #define TMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2004 Kazuki IWAMOTO"
 
@@ -99,7 +104,9 @@ typedef struct TmaidWindow_Tag
   GtkWidget *mark;          /* ja:タブの編集済みマーク */
   GtkWidget *menu_item;     /* ja:メニューのウインドウの項目 */
   GtkIMContext *im_context; /* ja:Input Method */
+#ifndef G_OS_WIN32
   GtkWidget *preedit;       /* ja:描画領域(未確定文字列) */
+#endif /* not G_OS_WIN32 */
 } TmaidWindow;
 
 
@@ -142,9 +149,14 @@ extern GdkColor system_color[12];
 extern GtkTargetEntry targets[4];/* ja:Text maidが提供可能なセレクション */
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
 /*
-表示色
+ja:表示色
  0,文字
  1,背景
  2,コントロールコード
